@@ -50,6 +50,13 @@ class KeywordArgumentAdapter(logging.LoggerAdapter):
         kwargs['extra'] = extra
         return msg, kwargs
 
+    if sys.version_info.major == 2:
+        def setLevel(self, level):
+            """
+            Set the specified level on the underlying logger.
+            """
+            self.logger.setLevel(level)
+
 
 _LOGGERS = weakref.WeakValueDictionary()
 
@@ -88,8 +95,12 @@ def setup(level=logging.WARNING, outputs=[output.STDERR], program_name=None,
         root_logger.removeHandler(handler)
 
     # Add configured handlers
-    for o in outputs:
-        o.add_to_logger(root_logger)
+    for out in outputs:
+        if isinstance(out, str):
+            out = output.preconfigured.get(out)
+            if out is None:
+                raise RuntimeError("Output {} is not available".format(out))
+        out.add_to_logger(root_logger)
 
     root_logger.setLevel(level)
 
